diff --git a/entity_browser.views.inc b/entity_browser.views.inc
index a026adc..c5a6d12 100644
--- a/entity_browser.views.inc
+++ b/entity_browser.views.inc
@@ -9,7 +9,7 @@
  * Implements hook_views_data_alter().
  */
 function entity_browser_views_data_alter(&$data) {
-  $entity_manager = \Drupal::entityManager();
+  $entity_manager = \Drupal::entityTypeManager();
   foreach ($entity_manager->getDefinitions() as $entity_type_name => $entity_type) {
     if (!empty($data[$entity_type->getBaseTable()])) {
       $entity_keys = $entity_type->get('entity_keys');
diff --git a/modules/entity_form/entity_browser_entity_form.module b/modules/entity_form/entity_browser_entity_form.module
index 41894b0..d4a6638 100644
--- a/modules/entity_form/entity_browser_entity_form.module
+++ b/modules/entity_form/entity_browser_entity_form.module
@@ -8,7 +8,7 @@ use \Drupal\Component\Utility\NestedArray;
  * Implements hook_inline_entity_form_reference_form_alter().
  */
 function entity_browser_entity_form_inline_entity_form_reference_form_alter(&$reference_form, \Drupal\Core\Form\FormStateInterface &$form_state) {
-  $entity_manager = \Drupal::entityManager();
+  $entity_manager = \Drupal::entityTypeManager();
   \Drupal::service('event_dispatcher')
     ->addListener(
       Events::REGISTER_JS_CALLBACKS,
@@ -86,11 +86,11 @@ function entity_browser_entity_form_reference_form_validate(&$reference_form, Fo
   $instance = $form_state->get(['inline_entity_form', $ief_id, 'instance']);
   $target_type = $instance->getFieldStorageDefinition()->getSetting('target_type');
   /** @var \Drupal\inline_entity_form\InlineEntityFormHandlerInterface $handler */
-  $handler = \Drupal::entityManager()->getHandler($target_type, 'inline_form');
+  $handler = \Drupal::entityTypeManager()->getHandler($target_type, 'inline_form');
   $labels = $handler->labels();
 
   $form_values = NestedArray::getValue($form_state->getValues(), $reference_form['#parents']);
-  $attach_entities = \Drupal::entityManager()->getStorage($entity_type)->loadMultiple(explode(' ', $form_values['entity_id']));
+  $attach_entities = \Drupal::entityTypeManager()->getStorage($entity_type)->loadMultiple(explode(' ', $form_values['entity_id']));
 
   // Check to see if entity is already referenced by current IEF widget
   if (!empty($attach_entities)) {
@@ -126,7 +126,7 @@ function entity_browser_entity_form_reference_form_submit($reference_form, FormS
   $entity_type = $reference_form['#entity_type'];
 
   $form_values = NestedArray::getValue($form_state->getValues(), $reference_form['#parents']);
-  $attach_entities = \Drupal::entityManager()->getStorage($entity_type)->loadMultiple(explode(' ', $form_values['entity_id']));
+  $attach_entities = \Drupal::entityTypeManager()->getStorage($entity_type)->loadMultiple(explode(' ', $form_values['entity_id']));
 
   // Determine the correct weight of the new element.
   $weight = 0;
diff --git a/src/Controllers/EntityBrowserController.php b/src/Controllers/EntityBrowserController.php
index a3f546b..2bb8fe2 100644
--- a/src/Controllers/EntityBrowserController.php
+++ b/src/Controllers/EntityBrowserController.php
@@ -30,7 +30,7 @@ class EntityBrowserController extends ControllerBase {
    */
   public function entityBrowserEdit(EntityInterface $entity) {
     // Build the entity edit form.
-    $form_object = $this->entityManager()->getFormObject($entity->getEntityTypeId(), 'edit');
+    $form_object = $this->entityTypeManager()->getFormObject($entity->getEntityTypeId(), 'edit');
     $form_object->setEntity($entity);
     $form_state = (new FormState())
       ->setFormObject($form_object)
diff --git a/src/EntityBrowserInterface.php b/src/EntityBrowserInterface.php
index cc5c614..150d639 100644
--- a/src/EntityBrowserInterface.php
+++ b/src/EntityBrowserInterface.php
@@ -8,7 +8,6 @@
 namespace Drupal\entity_browser;
 
 use Drupal\Core\Config\Entity\ConfigEntityInterface;
-use Drupal\Core\Form\FormStateInterface;
 
 /**
  * Provides an interface defining an entity browser entity.
diff --git a/src/Plugin/EntityBrowser/Display/Modal.php b/src/Plugin/EntityBrowser/Display/Modal.php
index 5e4e95b..ac07931 100644
--- a/src/Plugin/EntityBrowser/Display/Modal.php
+++ b/src/Plugin/EntityBrowser/Display/Modal.php
@@ -13,7 +13,6 @@ use Drupal\Core\Ajax\OpenModalDialogCommand;
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Routing\RouteMatchInterface;
 use Drupal\Core\Url;
-use Drupal\entity_browser\DisplayAjaxInterface;
 use Drupal\entity_browser\DisplayBase;
 use Drupal\entity_browser\DisplayRouterInterface;
 use Drupal\entity_browser\Events\Events;
@@ -22,7 +21,6 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\EventDispatcher\EventDispatcherInterface;
 use Drupal\Core\Path\CurrentPathStack;
 use Drupal\Core\Ajax\AjaxResponse;
-use Drupal\Core\Ajax\CloseDialogCommand;
 use Drupal\entity_browser\Ajax\SelectEntitiesCommand;
 use Symfony\Component\HttpKernel\Event\FilterResponseEvent;
 use Symfony\Component\HttpKernel\KernelEvents;
diff --git a/src/Plugin/EntityBrowser/Widget/Upload.php b/src/Plugin/EntityBrowser/Widget/Upload.php
index 913477f..83facf2 100644
--- a/src/Plugin/EntityBrowser/Widget/Upload.php
+++ b/src/Plugin/EntityBrowser/Widget/Upload.php
@@ -93,7 +93,7 @@ class Upload extends WidgetBase {
     $files = [];
     foreach ($form_state->getValue(['upload'], []) as $fid) {
       /** @var \Drupal\file\FileInterface $file */
-      $file = $this->entityManager->getStorage('file')->load($fid);
+      $file = \Drupal::entityTypeManager()->getStorage('file')->load($fid);
       $file->setPermanent();
       $file->save();
       $files[] = $file;
diff --git a/src/Plugin/EntityBrowser/FieldWidgetDisplay/ImageThumbnail.php b/src/Plugin/EntityBrowser/FieldWidgetDisplay/ImageThumbnail.php
index 33058f7..2add8d1 100644
--- a/src/Plugin/EntityBrowser/FieldWidgetDisplay/ImageThumbnail.php
+++ b/src/Plugin/EntityBrowser/FieldWidgetDisplay/ImageThumbnail.php
@@ -7,7 +7,7 @@
 namespace Drupal\entity_browser\Plugin\EntityBrowser\FieldWidgetDisplay;
 
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\Core\Entity\EntityManagerInterface;
+use Drupal\Core\Entity\EntityTypeManagerInterface;
 use Drupal\Core\Entity\EntityTypeInterface;
 use Drupal\Core\Form\FormStateInterface;
 use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
@@ -27,11 +27,11 @@ use Drupal\entity_browser\FieldWidgetDisplayBase;
 class ImageThumbnail extends FieldWidgetDisplayBase implements ContainerFactoryPluginInterface {
 
   /**
    * Entity manager service.
    *
-   * @var \Drupal\Core\Entity\EntityManagerInterface
+   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
    */
-  protected $entityManager;
+  protected $entityTypeManager;
 
   /**
    * Constructs widget plugin.
@@ -42,12 +42,12 @@ class ImageThumbnail extends FieldWidgetDisplayBase implements ContainerFactoryP
    *   The plugin_id for the plugin instance.
    * @param mixed $plugin_definition
    *   The plugin implementation definition.
-   * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
+   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
    *   Entity manager service.
    */
-  public function __construct(array $configuration, $plugin_id, $plugin_definition, EntityManagerInterface $entity_manager) {
+  public function __construct(array $configuration, $plugin_id, $plugin_definition, EntityTypeManagerInterface $entity_type_manager) {
     parent::__construct($configuration, $plugin_id, $plugin_definition);
-    $this->entityManager = $entity_manager;
+    $this->entityTypeManager = $entity_type_manager;
   }
 
   /**
@@ -58,7 +58,7 @@ class ImageThumbnail extends FieldWidgetDisplayBase implements ContainerFactoryP
       $configuration,
       $plugin_id,
       $plugin_definition,
-      $container->get('entity.manager')
+      $container->get('entity_type.manager')
     );
   }
 
@@ -80,7 +80,7 @@ class ImageThumbnail extends FieldWidgetDisplayBase implements ContainerFactoryP
    */
   public function settingsForm(array $form, FormStateInterface $form_state) {
     $options = [];
-    foreach ($this->entityManager->getStorage('image_style')->loadMultiple() as $id => $image_style) {
+    foreach ($this->entityTypeManager->getStorage('image_style')->loadMultiple() as $id => $image_style) {
       $options[$id] = $image_style->label();
     }
 
@@ -27,11 +27,11 @@ use Drupal\entity_browser\FieldWidgetDisplayBase;
 
   /**
-   * Entity manager service.
+   * Entity type manager service.
    *
diff --git a/src/Plugin/EntityBrowser/FieldWidgetDisplay/RenderedEntity.php b/src/Plugin/EntityBrowser/FieldWidgetDisplay/RenderedEntity.php
index a35d7a5..6e6fd5f 100644
--- a/src/Plugin/EntityBrowser/FieldWidgetDisplay/RenderedEntity.php
+++ b/src/Plugin/EntityBrowser/FieldWidgetDisplay/RenderedEntity.php
@@ -6,8 +6,9 @@
 
 namespace Drupal\entity_browser\Plugin\EntityBrowser\FieldWidgetDisplay;
 
+use Drupal\Core\Entity\EntityDisplayRepositoryInterface;
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\Core\Entity\EntityManagerInterface;
+use Drupal\Core\Entity\EntityTypeManagerInterface;
 use Drupal\Core\Form\FormStateInterface;
 use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
@@ -27,9 +28,16 @@ class RenderedEntity extends FieldWidgetDisplayBase implements ContainerFactoryP
   /**
    * Entity manager service.
    *
-   * @var \Drupal\Core\Entity\EntityManagerInterface
+   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
    */
-  protected $entityManager;
+  protected $entityTypeManager;
+
+  /**
+   * Entity display repository.
+   *
+   * @var \Drupal\Core\Entity\EntityDisplayRepositoryInterface
+   */
+  protected $entityDisplayRepository;
 
   /**
    * Constructs widget plugin.
@@ -40,12 +48,15 @@ class RenderedEntity extends FieldWidgetDisplayBase implements ContainerFactoryP
    *   The plugin_id for the plugin instance.
    * @param mixed $plugin_definition
    *   The plugin implementation definition.
    * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
    *   Entity manager service.
    */
-  public function __construct(array $configuration, $plugin_id, $plugin_definition, EntityManagerInterface $entity_manager) {
+  public function __construct(array $configuration, $plugin_id, $plugin_definition, EntityTypeManagerInterface $entity_type_manager, EntityDisplayRepositoryInterface $entity_display_repository) {
     parent::__construct($configuration, $plugin_id, $plugin_definition);
-    $this->entityManager = $entity_manager;
+    $this->entityTypeManager = $entity_type_manager;
+    $this->entityDisplayRepository = $entity_display_repository;
   }
 
   /**
@@ -56,7 +67,8 @@ class RenderedEntity extends FieldWidgetDisplayBase implements ContainerFactoryP
       $configuration,
       $plugin_id,
       $plugin_definition,
-      $container->get('entity.manager')
+      $container->get('entity_type.manager'),
+      $container->get('entity_display.repository')
     );
   }
 
@@ -64,7 +76,7 @@ class RenderedEntity extends FieldWidgetDisplayBase implements ContainerFactoryP
    * {@inheritdoc}
    */
   public function view(EntityInterface $entity) {
-    return $this->entityManager->getViewBuilder($this->configuration['entity_type'])->view($entity, $this->configuration['view_mode']);
+    return $this->entityTypeManager->getViewBuilder($this->configuration['entity_type'])->view($entity, $this->configuration['view_mode']);
   }
 
   /**
@@ -72,7 +84,7 @@ class RenderedEntity extends FieldWidgetDisplayBase implements ContainerFactoryP
    */
   public function settingsForm(array $form, FormStateInterface $form_state) {
     $options = [];
-    foreach ($this->entityManager->getViewModes($this->configuration['entity_type']) as $id => $view_mode) {
+    foreach ($this->entityDisplayRepository->getViewModes($this->configuration['entity_type']) as $id => $view_mode) {
       $options[$id] = $view_mode['label'];
     }
 
@@ -40,12 +48,15 @@ class RenderedEntity extends FieldWidgetDisplayBase implements ContainerFactoryP
    * @param mixed $plugin_definition
    *   The plugin implementation definition.
-   * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
-   *   Entity manager service.
+   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
+   *   Entity type manager service.
+   * @param \Drupal\Core\Entity\EntityDisplayRepositoryInterface $entity_display_repository
+   *   Entity display repository service.
    */
diff --git a/src/Plugin/Field/FieldWidget/EntityReference.php b/src/Plugin/Field/FieldWidget/EntityReference.php
index 21a0e0c..6cb8fc9 100644
--- a/src/Plugin/Field/FieldWidget/EntityReference.php
+++ b/src/Plugin/Field/FieldWidget/EntityReference.php
@@ -10,7 +10,7 @@ namespace Drupal\entity_browser\Plugin\Field\FieldWidget;
 use Drupal\Component\Utility\Html;
 use Drupal\Component\Utility\NestedArray;
 use Drupal\Core\Entity\ContentEntityInterface;
-use Drupal\Core\Entity\EntityManagerInterface;
+use Drupal\Core\Entity\EntityTypeManagerInterface;
 use Drupal\Core\Field\FieldDefinitionInterface;
 use Drupal\Core\Field\FieldItemListInterface;
 use Drupal\Core\Field\FieldStorageDefinitionInterface;
@@ -18,8 +18,6 @@ use Drupal\Core\Field\WidgetBase;
 use Drupal\Core\Form\FormStateInterface;
 use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
 use Drupal\Core\Url;
-use Drupal\entity_browser\Events\Events;
-use Drupal\entity_browser\Events\RegisterJSCallbacks;
 use Drupal\entity_browser\FieldWidgetDisplayManager;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\EventDispatcher\EventDispatcherInterface;
@@ -40,11 +38,11 @@ use Symfony\Component\EventDispatcher\EventDispatcherInterface;
 class EntityReference extends WidgetBase implements ContainerFactoryPluginInterface {
 
   /**
-   * Entity manager service
+   * Entity type manager service
    *
-   * @var \Drupal\Core\Entity\EntityManagerInterface
+   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
    */
-  protected $entityManager;
+  protected $entityTypeManager;
 
   /**
    * Field widget display plugin manager.
@@ -75,16 +73,16 @@ class EntityReference extends WidgetBase implements ContainerFactoryPluginInterf
    *   The widget settings.
    * @param array $third_party_settings
    *   Any third party settings.
    * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
    *   Entity manager service.
    * @param \Symfony\Component\EventDispatcher\EventDispatcherInterface $event_dispatcher
    *   Event dispatcher.
    * @param \Drupal\entity_browser\FieldWidgetDisplayManager $field_display_manager
    *   Field widget display plugin manager.
    */
-  public function __construct($plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, array $settings, array $third_party_settings, EntityManagerInterface $entity_manager, EventDispatcherInterface $event_dispatcher, FieldWidgetDisplayManager $field_display_manager) {
+  public function __construct($plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, array $settings, array $third_party_settings, EntityTypeManagerInterface $entity_type_manager, EventDispatcherInterface $event_dispatcher, FieldWidgetDisplayManager $field_display_manager) {
     parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $third_party_settings);
-    $this->entityManager = $entity_manager;
+    $this->entityTypeManager = $entity_type_manager;
     $this->fieldDisplayManager = $field_display_manager;
   }
 
@@ -98,7 +96,7 @@ class EntityReference extends WidgetBase implements ContainerFactoryPluginInterf
       $configuration['field_definition'],
       $configuration['settings'],
       $configuration['third_party_settings'],
-      $container->get('entity.manager'),
+      $container->get('entity_type.manager'),
       $container->get('event_dispatcher'),
       $container->get('plugin.manager.entity_browser.field_widget_display')
     );
@@ -126,7 +124,7 @@ class EntityReference extends WidgetBase implements ContainerFactoryPluginInterf
 
     $browsers = [];
     /** @var \Drupal\entity_browser\EntityBrowserInterface $browser */
-    foreach ($this->entityManager->getStorage('entity_browser')->loadMultiple() as $browser) {
+    foreach ($this->entityTypeManager->getStorage('entity_browser')->loadMultiple() as $browser) {
       $browsers[$browser->id()] = $browser->label();
     }
 
@@ -138,7 +136,7 @@ class EntityReference extends WidgetBase implements ContainerFactoryPluginInterf
     ];
 
     $target_type = $this->fieldDefinition->getFieldStorageDefinition()->getSetting('target_type');
-    $entity_type = \Drupal::entityTypeManager()->getStorage($target_type)->getEntityType();
+    $entity_type = $this->entityTypeManager->getStorage($target_type)->getEntityType();
 
     $displays = [];
     foreach ($this->fieldDisplayManager->getDefinitions() as $id => $definition) {
@@ -243,7 +241,7 @@ class EntityReference extends WidgetBase implements ContainerFactoryPluginInterf
    */
   function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
     $entity_type = $this->fieldDefinition->getFieldStorageDefinition()->getSetting('target_type');
-    $entity_storage = $this->entityManager->getStorage($entity_type);
+    $entity_storage = $this->entityTypeManager->getStorage($entity_type);
 
     $ids = [];
     $entities = [];
@@ -311,7 +309,7 @@ class EntityReference extends WidgetBase implements ContainerFactoryPluginInterf
     $hidden_id = Html::getUniqueId('edit-' . $this->fieldDefinition->getName() . '-target-id');
     $details_id = Html::getUniqueId('edit-' . $this->fieldDefinition->getName());
     /** @var \Drupal\entity_browser\EntityBrowserInterface $entity_browser */
-    $entity_browser = $this->entityManager->getStorage('entity_browser')->load($this->getSetting('entity_browser'));
+    $entity_browser = $this->entityTypeManager->getStorage('entity_browser')->load($this->getSetting('entity_browser'));
 
     $element += [
       '#id' => $details_id,
@@ -75,16 +73,16 @@ class EntityReference extends WidgetBase implements ContainerFactoryPluginInterf
    * @param array $third_party_settings
    *   Any third party settings.
-   * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
-   *   Entity manager service.
+   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
+   *   Entity type manager service.
    * @param \Symfony\Component\EventDispatcher\EventDispatcherInterface $event_dispatcher
    *   Event dispatcher.
